Function_construction: Function Construction

View source: R/Function_construction.R

Function_constructionR Documentation

Function Construction

Description

This function allows the user to create the target function in an interactive manner. Here, the target function is expressed as

f(\boldsymbol{\theta})=f_J(\theta_{1},\ldots,\theta_{p},f_1,\ldots,f_{J-1}),

where

  • f_1 is a function of \theta_{1},\ldots,\theta_{p};

  • f_j is a function of \theta_{1},\ldots,\theta_{p},f_1,\ldots,f_{j-1}, for j=2,\ldots,J;

  • f_1,\ldots,f_J belongs to the bank of assembly functions.

Here, user can input the function by

  1. inputting the dimensionality p;

  2. for j=1,\ldots,J;

    1. selecting which assembly function f_j belongs to;

    2. inputting the indexes of coefficients or existing functions included as arguments of f_j;

    3. inputting the coefficients.

Usage

Function_construction()

Value

An R list depicting the target function.


MMAD documentation built on March 12, 2026, 5:07 p.m.