Function_evaluation: Function Evaluation

View source: R/Function_evaluation.R

Function_evaluationR Documentation

Function Evaluation

Description

This function allows the user to compute the value, gradients and the Hessian matrix of the target function f(\boldsymbol{\theta}) at a given point \boldsymbol{\theta}^*.

Usage

Function_evaluation(Function_obj, input)

Arguments

Function_obj

An R list depicting the target function.

input

The value \boldsymbol{\theta}^* at which the target function is evaluated.

Value

An R list recording the value, gradients and the Hessian matrix of the target function f(\boldsymbol{\theta}) at a given point \boldsymbol{\theta}^*.


MMAD documentation built on March 12, 2026, 5:07 p.m.