View source: R/Function_construction.R
| Function_construction | R Documentation |
This function allows the user to create the target function in an interactive manner. Here, the target function is expressed as
f(\boldsymbol{\theta})=f_J(\theta_{1},\ldots,\theta_{p},f_1,\ldots,f_{J-1}),
where
f_1 is a function of \theta_{1},\ldots,\theta_{p};
f_j is a function of \theta_{1},\ldots,\theta_{p},f_1,\ldots,f_{j-1}, for j=2,\ldots,J;
f_1,\ldots,f_J belongs to the bank of assembly functions.
Here, user can input the function by
inputting the dimensionality p;
for j=1,\ldots,J;
selecting which assembly function f_j belongs to;
inputting the indexes of coefficients or existing functions included as arguments of f_j;
inputting the coefficients.
Function_construction()
An R list depicting the target function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.