View source: R/Function_evaluation.R
| Function_evaluation | R Documentation |
This function allows the user to compute the value, gradients and the Hessian matrix of the target function f(\boldsymbol{\theta}) at a given point \boldsymbol{\theta}^*.
Function_evaluation(Function_obj, input)
Function_obj |
An R list depicting the target function. |
input |
The value |
An R list recording the value, gradients and the Hessian matrix of the target function f(\boldsymbol{\theta}) at a given point \boldsymbol{\theta}^*.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.